[tor-commits] [gettor/master] Update stats update to add locale

hiro at torproject.org hiro at torproject.org
Thu May 23 15:14:12 UTC 2019


commit 1f016f1f72d18e049722df70564bfd6d92e4c340
Author: hiro <hiro at torproject.org>
Date:   Thu May 23 17:14:08 2019 +0200

    Update stats update to add locale
---
 gettor/services/email/sendmail.py | 3 ++-
 gettor/utils/db.py                | 8 ++++----
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/gettor/services/email/sendmail.py b/gettor/services/email/sendmail.py
index 0af0af8..82c3288 100644
--- a/gettor/services/email/sendmail.py
+++ b/gettor/services/email/sendmail.py
@@ -208,7 +208,8 @@ class Sendmail(object):
                     )
 
                     yield self.conn.update_stats(
-                        command="links", platform=platform, service="email"
+                        command="links", platform=platform, language=locale,
+                        service="email"
                     )
 
                     yield self.conn.update_request(
diff --git a/gettor/utils/db.py b/gettor/utils/db.py
index 73610ed..083020d 100644
--- a/gettor/utils/db.py
+++ b/gettor/utils/db.py
@@ -83,17 +83,17 @@ class SQLite3(object):
 			query, (hid, status, id, service, date)
 		).addCallback(self.query_callback).addErrback(self.query_errback)
 
-	def update_stats(self, command, service, platform=None):
+	def update_stats(self, command, service, platform=None, language='en'):
 		"""
 		Update statistics to the database
 		"""
 		now_str = datetime.now().strftime("%Y%m%d")
-		query = "REPLACE INTO stats(num_requests, platform, "\
+		query = "REPLACE INTO stats(num_requests, platform, language, "\
 		"command, service, date) VALUES(COALESCE((SELECT num_requests FROM stats "\
-		"WHERE date=?)+1, 0), ?, ?, ?, ?) "\
+		"WHERE date=?)+1, 0), ?, ?, ?, ?, ?) "\
 
 		return self.dbpool.runQuery(
 			query, (now_str,platform, command, service, now_str)
 		).addCallback(self.query_callback).addErrback(self.query_errback)
 
 	def get_links(self, platform, language, status):
@@ -83,17 +83,17 @@ class SQLite3(object):
 
 		return self.dbpool.runQuery(
-			query, (now_str,platform, command, service, now_str)
+			query, (now_str, platform, language, command, service, now_str)
 		).addCallback(self.query_callback).addErrback(self.query_errback)
 



More information about the tor-commits mailing list